@@ -12,6 +12,12 @@ class ForbiddenTemplateError(ForbiddenResourceError):
 class ForbiddenCampaignError(ForbiddenResourceError):
     """Campaign is not owned by clients' user"""
 
+class ForbiddenCardError(ForbiddenResourceError):
+    """Card is not owned by clients' user"""
+
+class ForbiddenContactError(ForbiddenResourceError):
+    """Contact is not owned by clients' user"""
+
 class ShippingAddressError(AMcardsException, ValueError):
     """Some shipping address fields are missing or invalid"""
 
